Crate echo_core

Crate echo_core 

echo-core

Core traits, types, and error definitions for the echo-agent framework.

This crate provides the shared interfaces that all other workspace crates build on:

ModuleContents
agentAgent trait, AgentEvent, AgentCallback, CancellationToken
llmLlmClient trait, ChatRequest/ChatResponse/ChatChunk types
toolsTool trait, ToolResult, ToolPermission, permission model
errorUnified Error enum covering all failure modes
guardGuard trait, GuardResult, GuardManager
auditAuditEvent, AuditLogger trait
retryRetryPolicy with exponential backoff
tokenizerToken counting interface

Most users should depend on echo_agent (the facade crate) instead of depending on echo_core directly.

Modules

agent
Agent core trait, events, and callback interfaces
audit
Audit logging core trait and event types
circuit_breaker
LLM Circuit Breaker
error
Unified error types
guard
Guard system core trait and types
llm
LLM client core trait and request/response types
project_rules
Project-level rules file loading
retry
Unified retry policy
tokenizer
Token estimation trait, usage tracking, and cost estimation
tools
Tool system core trait and types